==> session_reminder-1.0.1.tar.gz: session_reminder/src/Form/ConfigForm.php <==
<?php

namespace Drupal\session_reminder\Form;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\session_reminder\Helper\SessionHelper;
use Drupal\session_reminder\Helper\SessionReminderHelper;
use Drupal\user\Entity\Role;

/**
 * Provides a ConfigForm to manage Session Reminder settings.
 */
class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sr__config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('session_reminder.settings');
    $cookieLifetime = SessionReminderHelper::getCookieLifetime();
    $expTimestamp = SessionHelper::getExpTimestamp();
    if (!$cookieLifetime){
      \Drupal::messenger()->addError($this->t('Unable to detect Cookie Lifetime or setted to 0 (no expire).'));
      \Drupal::messenger()->addError($this->t('You need to set a value for session.cooke_lifetime in services.yml to enabled alert.'));
      return $form;
    }

    $form['sr__config_form'] = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#open' => TRUE,
    ];

    $expDate = ($expTimestamp>0)?DrupalDateTime::createFromTimestamp($expTimestamp):null;
    $expDateFormatted = ($expDate)?$expDate->format('Y-m-d H:i:s'):"N/A";
    $seconds = $config->get('warning_threshold');
    $modalTimestamp = ($expTimestamp>0)?($expTimestamp - $seconds):null;
    $modalDate = ($expTimestamp>0 && $modalTimestamp>0)?DrupalDateTime::createFromTimestamp($modalTimestamp):null;
    $modalDateFormatted = ($modalDate)?$modalDate->format('Y-m-d H:i:s'):"N/A";
    $description = "<li>". $this->t('Your Drupal\'s Cookie Session are set to expire after @lifetime seconds.', ['@lifetime'=>$cookieLifetime])."</li>";
    $description .= "<li>". $this->t('Your Current Cookie Session will expire on @date.', ['@date'=>$expDateFormatted])."</li>";
    $description .= "<li>". $this->t('Modal for you session will be shown on @datemodal.', ['@datemodal'=>$modalDateFormatted])."</li>";

    $form['sr__config_form']['description'] = [
      '#type' => 'container',
      '#markup' => "<b>".$this->t('Details')."</b>:<ul>".$description."</ul>",
      '#attributes' => array('style' => 'font-size:10pt; margin-bottom: 10px'),
      '#open' => TRUE,
    ];

    $form['sr__config_form']['warning_threshold'] = [
      '#type' => 'number',
      '#description' => $this->t('Set how many seconds before the session expiration the modal should appear.'),
      '#title' => $this->t('Warning Threshold'),
      '#max' => $cookieLifetime,
      '#min' => 10,
      '#required' => TRUE,
      '#default_value' => $config->get('warning_threshold')
    ];

    $roles = Role::loadMultiple();
    $options = [];

    // Aggiungi l'opzione "Tutti i ruoli"
    $options['all'] = $this->t('All roles');
    // Aggiungi tutti i ruoli del sito
    foreach ($roles as $role) {
      if ($role->id()== AccountInterface::ANONYMOUS_ROLE) {
        continue;
      }
      $options[$role->id()] = $role->label();
    }

    $form['sr__config_form']['roles'] = [
      '#type' => 'select',
      '#title' => $this->t('Roles'),
      '#description' => $this->t('Select one or more roles that will see the modal'),
      '#options' => $options,
      '#multiple' => TRUE,
      '#default_value' => $config->get('roles') ?: ['all']
    ];

    $form['sr__config_form_style'] = [
      '#type' => 'details',
      '#title' => $this->t('Style'),
      '#open' => TRUE,
    ];

    $template = "
        <div id='preview--sr--modal-form'>
          <div><span class='preview--sr--modal-form--cancel'>X</span></div>
          <div>
            <span id='preview--sr--modal-form--h2'>".$this->t('Session expiring')."</span>
            <span id='preview--sr--modal-form--p'>".$this->t("Your session will expire in @sec seconds",['@sec'=>0])."</span>
          </div>
          <div class='preview--sr--form-actions'>
            <span id='preview--sr--modal-form--btn'>".$this->t('Extend Session')."</span>
          </div>
        </div>";

    $form['sr__config_form_style']['live_preview_description'] = [
      '#type' => 'container',
      '#markup'=> "<p><b>" . $this->t('Live Preview') . "</b></p>"
    ];

    $form['sr__config_form_style']['live_preview'] = [
      '#type' => 'container',
      '#markup' => $template,
      '#attributes' => ['id' => 'preview--sr--modal-form-container'],
    ];


    $form['sr__config_form_style']['color_modal_bg'] = [
      '#type' => 'color',
      '#title' => $this->t('Modal Background Color'),
      '#default_value' => $config->get('color_modal_bg') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the Modal background.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form',
        'data-preview-property' => 'background-color'
      ]
    ];

    $form['sr__config_form_style']['color_modal_title'] = [
      '#type' => 'color',
      '#title' => $this->t('Modal Title Color'),
      '#default_value' => $config->get('color_modal_title') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the Modal title.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--h2',
        'data-preview-property' => 'color',
      ]
    ];

    $form['sr__config_form_style']['color_modal_text'] = [
      '#type' => 'color',
      '#title' => $this->t('Modal Text Color'),
      '#default_value' => $config->get('color_modal_text') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the Modal text.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--p',
        'data-preview-property' => 'color',
      ]
    ];

    $form['sr__config_form_style']['color_btn_bg'] = [
      '#type' => 'color',
      '#title' => $this->t('Submit Button Bg Color'),
      '#default_value' => $config->get('color_btn_bg') ?? '#20478c',
      '#description' => $this->t('Choose the color for the \'Extend Session\'/\'Close\' button.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--btn',
        'data-preview-property' => 'background-color',
      ],
    ];

    $form['sr__config_form_style']['color_btn_text'] = [
      '#type' => 'color',
      '#title' => $this->t('Submit Button Text Color'),
      '#default_value' => $config->get('color_btn_text') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the \'Extend Session\'/\'Close\' text.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--btn',
        'data-preview-property' => 'color',
      ]
    ];

    $form['sr__config_form_style']['modal_border_radius'] = [
      '#type' => 'number',
      '#title' => $this->t('Modal Border Radius'),
      '#default_value' => $config->get('modal_border_radius') ?? 10,
      '#description' => $this->t('Choose the border radius form modal.'),
      '#max' => 999,
      '#min' => 0,
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form',
        'data-preview-property' => 'border-radius',
      ]
    ];

    $form['#attached']['library'][] = 'session_reminder/modal-form-preview-library';
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('session_reminder.settings')
      ->set('warning_threshold', $form_state->getValue('warning_threshold'))
      ->set('roles', $form_state->getValue('roles'))
      ->set('color_btn_bg', $form_state->getValue('color_btn_bg'))
      ->set('color_btn_text', $form_state->getValue('color_btn_text'))
      ->set('color_modal_title', $form_state->getValue('color_modal_title'))
      ->set('color_modal_bg', $form_state->getValue('color_modal_bg'))
      ->set('color_modal_text', $form_state->getValue('color_modal_text'))
      ->set('modal_border_radius', $form_state->getValue('modal_border_radius'))
      ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['session_reminder.settings'];
  }

}

==> session_reminder-1.0.2.tar.gz: session_reminder/src/Form/ConfigForm.php <==
<?php

namespace Drupal\session_reminder\Form;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\session_reminder\Helper\SessionHelper;
use Drupal\session_reminder\Helper\SessionReminderHelper;
use Drupal\user\Entity\Role;

/**
 * Provides a ConfigForm to manage Session Reminder settings.
 */
class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sr__config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('session_reminder.settings');
    $cookieLifetime = SessionReminderHelper::getCookieLifetime();
    $expTimestamp = SessionHelper::getExpTimestamp();
    if (!$cookieLifetime) {
      \Drupal::messenger()->addError($this->t('Unable to detect Cookie Lifetime or setted to 0 (no expire).'));
      \Drupal::messenger()->addError($this->t('You need to set a value for session.cooke_lifetime in services.yml to enabled alert.'));
      return $form;
    }

    $form['sr__config_form'] = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#open' => TRUE,
    ];

    $expDate = ($expTimestamp > 0) ? DrupalDateTime::createFromTimestamp($expTimestamp) : NULL;
    $expDateFormatted = ($expDate) ? $expDate->format('Y-m-d H:i:s') : "N/A";
    $seconds = $config->get('warning_threshold');
    $modalTimestamp = ($expTimestamp > 0) ? ($expTimestamp - $seconds) : NULL;
    $modalDate = ($expTimestamp > 0 && $modalTimestamp > 0) ? DrupalDateTime::createFromTimestamp($modalTimestamp) : NULL;
    $modalDateFormatted = ($modalDate) ? $modalDate->format('Y-m-d H:i:s') : "N/A";
    $description = [
      $this->t("Your Drupal's Cookie Session are set to expire after @lifetime seconds.", ['@lifetime' => $cookieLifetime]),
      $this->t('Your Current Cookie Session will expire on @date.', ['@date' => $expDateFormatted]),
      $this->t('Modal for your session will be shown on @datemodal.', ['@datemodal' => $modalDateFormatted]),
    ];

    $descriptionMarkup = $this->t('<b>Details</b>:<ul>@items</ul>', [
      '@items' => '<li>' . implode('</li><li>', $description) . '</li>',
    ]);

    $form['sr__config_form']['description'] = [
      '#type' => 'container',
      '#markup' => $descriptionMarkup,
      '#attributes' => ['style' => 'font-size:10pt; margin-bottom: 10px'],
      '#open' => TRUE,
    ];

    $form['sr__config_form']['warning_threshold'] = [
      '#type' => 'number',
      '#description' => $this->t('Set how many seconds before the session expiration the modal should appear.'),
      '#title' => $this->t('Warning Threshold'),
      '#max' => $cookieLifetime,
      '#min' => 10,
      '#required' => TRUE,
      '#default_value' => $config->get('warning_threshold'),
    ];

    $roles = Role::loadMultiple();
    $options = [];

    // Aggiungi l'opzione "Tutti i ruoli".
    $options['all'] = $this->t('All roles');
    // Aggiungi tutti i ruoli del sito.
    foreach ($roles as $role) {
      if ($role->id() == AccountInterface::ANONYMOUS_ROLE) {
        continue;
      }
      $options[$role->id()] = $role->label();
    }

    $form['sr__config_form']['roles'] = [
      '#type' => 'select',
      '#title' => $this->t('Roles'),
      '#description' => $this->t('Select one or more roles that will see the modal'),
      '#options' => $options,
      '#multiple' => TRUE,
      '#default_value' => $config->get('roles') ?: ['all'],
    ];

    $form['sr__config_form_style'] = [
      '#type' => 'details',
      '#title' => $this->t('Style'),
      '#open' => TRUE,
    ];

    $template = "
        <div id='preview--sr--modal-form'>
          <div><span class='preview--sr--modal-form--cancel'>X</span></div>
          <div>
            <span id='preview--sr--modal-form--h2'>" . $this->t('Session expiring') . "</span>
            <span id='preview--sr--modal-form--p'>" . $this->t("Your session will expire in @sec seconds", ['@sec' => 0]) . "</span>
          </div>
          <div class='preview--sr--form-actions'>
            <span id='preview--sr--modal-form--btn'>" . $this->t('Extend Session') . "</span>
          </div>
        </div>";

    $form['sr__config_form_style']['live_preview_description'] = [
      '#type' => 'container',
      '#markup' => "<p><b>" . $this->t('Live Preview') . "</b></p>",
    ];

    $form['sr__config_form_style']['live_preview'] = [
      '#type' => 'container',
      '#markup' => $template,
      '#attributes' => ['id' => 'preview--sr--modal-form-container'],
    ];

    $form['sr__config_form_style']['color_modal_bg'] = [
      '#type' => 'color',
      '#title' => $this->t('Modal Background Color'),
      '#default_value' => $config->get('color_modal_bg') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the Modal background.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form',
        'data-preview-property' => 'background-color',
      ],
    ];

    $form['sr__config_form_style']['color_modal_title'] = [
      '#type' => 'color',
      '#title' => $this->t('Modal Title Color'),
      '#default_value' => $config->get('color_modal_title') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the Modal title.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--h2',
        'data-preview-property' => 'color',
      ],
    ];

    $form['sr__config_form_style']['color_modal_text'] = [
      '#type' => 'color',
      '#title' => $this->t('Modal Text Color'),
      '#default_value' => $config->get('color_modal_text') ?? '#ffffff',
      '#description' => $this->t('Choose the color for the Modal text.'),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--p',
        'data-preview-property' => 'color',
      ],
    ];

    $form['sr__config_form_style']['color_btn_bg'] = [
      '#type' => 'color',
      '#title' => $this->t('Submit Button Bg Color'),
      '#default_value' => $config->get('color_btn_bg') ?? '#20478c',
      '#description' => $this->t("Choose the color for the 'Extend Session'/'Close' button."),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--btn',
        'data-preview-property' => 'background-color',
      ],
    ];

    $form['sr__config_form_style']['color_btn_text'] = [
      '#type' => 'color',
      '#title' => $this->t('Submit Button Text Color'),
      '#default_value' => $config->get('color_btn_text') ?? '#ffffff',
      '#description' => $this->t("Choose the color for the 'Extend Session'/'Close' text.'"),
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form--btn',
        'data-preview-property' => 'color',
      ],
    ];

    $form['sr__config_form_style']['modal_border_radius'] = [
      '#type' => 'number',
      '#title' => $this->t('Modal Border Radius'),
      '#default_value' => $config->get('modal_border_radius') ?? 10,
      '#description' => $this->t('Choose the border radius form modal.'),
      '#max' => 999,
      '#min' => 0,
      '#attributes' => [
        'class' => ['live-preview'],
        'data-preview-target' => 'preview--sr--modal-form',
        'data-preview-property' => 'border-radius',
      ],
    ];

    $form['#attached']['library'][] = 'session_reminder/modal-form-preview-library';
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('session_reminder.settings')
      ->set('warning_threshold', $form_state->getValue('warning_threshold'))
      ->set('roles', $form_state->getValue('roles'))
      ->set('color_btn_bg', $form_state->getValue('color_btn_bg'))
      ->set('color_btn_text', $form_state->getValue('color_btn_text'))
      ->set('color_modal_title', $form_state->getValue('color_modal_title'))
      ->set('color_modal_bg', $form_state->getValue('color_modal_bg'))
      ->set('color_modal_text', $form_state->getValue('color_modal_text'))
      ->set('modal_border_radius', $form_state->getValue('modal_border_radius'))
      ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['session_reminder.settings'];
  }

}
